# Rolldecay-estimators Package
- Transformers and estimators for scikit-learn
rolldecay-estimators is a scikit-learn compatible extension.

It aids development of estimators that can be used in scikit-learn pipelines and (hyper)parameter search, 
while facilitating testing (including some API compliance), documentation, open source development, packaging, and 
continuous integration.

Refer to the documentation to modify the template for your own scikit-learn contribution.

Thank you for cleanly contributing to the scikit-learn ecosystem!

[Github: rolldecay-estimators](https://github.com/martinlarsalbert/rolldecay-estimators)